package com.anytypeio.anytype.presentation.objects.custom_icon

/**
 * Data class representing a custom icon.
 * @property rawValue The raw string representing the icon.
 * @property color The color of the icon, if any.
 */
data class CustomIcon(
    val rawValue: String,
    val color: CustomIconColor = CustomIconColor.DEFAULT
) {
    /**
     * Returns the drawable resource name for this icon.
     *
     * The drawable name is generated by converting [rawValue] from kebab-case
     * (e.g., "battery-dead") to snake_case ("battery_dead") and prefixing it with "ci_".
     */
    val drawableResId: String
        get() = DEFAULT_ICON_PREFIX + rawValue.toSnakeCase()

    companion object {
        const val DEFAULT_ICON_PREFIX = "ci_"
    }
}

/**
 * Extension function that converts a kebab-case string to snake_case.
 *
 * Simply replaces all occurrences of '-' with '_'.
 *
 * @receiver String to be converted.
 * @return The snake_case version of the string.
 */
private fun String.toSnakeCase(): String = replace("-", "_")